
pdf(paste0("./output/", output_path, "/pi0_vs_pi1.pdf"))
plot(pi_intercept_sim, pi_slope_sim, pch=".", col=rgb(0,0,0, alpha=1/100))
dev.off()	


pdf(paste0("./output/", output_path, "/sim_CI_dist.pdf"))
par(xpd=xpd_val)
plot(NULL, xlim=c(underline_delta, overline_delta), ylim=c(underline_delta, overline_delta), xlab="$\\delta_I$", ylab="$\\delta_h$", xaxs="i", yaxs="i")
for (i in 1:nSamp)
{
  abline(a=pi_intercept_sim[i], b=pi_slope_sim[i], col=rgb(0.5,0,0,alpha=100/10000), lwd=1/10)
}
abline(a=0,b=1,lty=2, lwd=1, col="blue")
legend("bottomright", legend=c("$\\delta_I=\\delta_h$"), lty=c(2), lwd=c(1), col=c("blue"), bty="n")
dev.off()

tikz(file=paste0("./output/", output_path, "/sim_CI_dist.tex"), standAlone=FALSE, sanitize=FALSE)
par(xpd=xpd_val)
plot(NULL, xlim=c(underline_delta, overline_delta), ylim=c(underline_delta, overline_delta), xlab="$\\delta_I$", ylab="$\\delta_h$", xaxs="i", yaxs="i")
for (i in 1:nSamp)
{
  abline(a=pi_intercept_sim[i], b=pi_slope_sim[i], col=rgb(0.5,0,0,alpha=100/10000), lwd=1/10)
}
abline(a=0,b=1,lty=2, lwd=1, col="blue")
legend("bottomright", legend=c("$\\delta_I=\\delta_h$"), lty=c(2), lwd=c(1), col=c("blue"), bty="n")
dev.off()

# holds lb and ub for all 6 versions (this_version)
lb_ub_by_version<-array(NA, dim=c(nSamp, 2, 6), dimnames=list(1:nSamp, c("lb", "ub"), 1:6))

this_version<-0

## estimated bounds and confidence sets

# delta_h
this_version<-this_version+1
print(paste("version:", this_version))

## no assumption about RTS
est_bounds<-data.frame(parameter=character(), ass=integer(), lb=double(), ub=double(), stringsAsFactors = FALSE)

lb<- pi_intercept_sim
ub<- pi_intercept_sim + pi_slope_sim  
lb<- pmax(underline_delta, pmin(overline_delta, lb))
ub<- pmax(underline_delta, pmin(overline_delta, ub))
lb_ub_by_version[,"lb",this_version]<-lb
lb_ub_by_version[,"ub",this_version]<-ub

newrow<-data.frame("delta_h", 1, 
                   max(underline_delta, mean(lb)), 
                   min(overline_delta, mean(ub)))
names(newrow)<-names(est_bounds)
this_est_bounds<-newrow
est_bounds<-rbind(est_bounds, newrow)

## "homegrown" confidence sets: these contain the points
homegrown_point_conf_sets<-data.frame(parameter=character(), ass=integer(), size=double(), lb=double(), ub=double(), stringsAsFactors = FALSE)

for (this_size_alpha in c(size_alpha, 2*size_alpha)){
  vec_lower_tail_probs<-seq(0, this_size_alpha, length=size_asym_alpha_grid)
  tmp_array<-array(NA, dim=c(size_asym_alpha_grid, 3), dimnames=list(1:size_asym_alpha_grid, c("lb", "ub", "width")))
  for (rr in 1:size_asym_alpha_grid){
    this_lower_tail_prob<-vec_lower_tail_probs[rr]
    this_upper_tail_prob<-this_size_alpha-this_lower_tail_prob
    tmp_array[rr,c("lb", "ub")]<-c(quantile(lb, this_lower_tail_prob), quantile(ub, 1-this_lower_tail_prob))
  }
  tmp_array[,"width"]<-tmp_array[,"ub"] - tmp_array[,"lb"]
  row_for_best_conf_set<-which.min(tmp_array[,"width"])
  best_conf_set<-tmp_array[row_for_best_conf_set,]
  newrow<-data.frame("delta_h", 1, 1-this_size_alpha, 
                     best_conf_set["lb"], 
                     best_conf_set["ub"])
  names(newrow)<-names(homegrown_point_conf_sets)
  homegrown_point_conf_sets<-rbind(homegrown_point_conf_sets, newrow)
}

this_version<-this_version+1
print(paste("version:", this_version))

## non-increasing returns to scale
lb<- pi_intercept_sim
ub<- (pi_intercept_sim + pi_slope_sim)/(1 + pi_slope_sim)  
lb<- pmax(underline_delta, pmin(overline_delta, lb))
ub<- pmax(underline_delta, pmin(overline_delta, ub))
lb_ub_by_version[,"lb",this_version]<-lb
lb_ub_by_version[,"ub",this_version]<-ub

### est bounds
newrow<-data.frame("delta_h", 2, 
                   max(underline_delta, mean(lb)), 
                   min(overline_delta, mean(ub)))
names(newrow)<-names(est_bounds)
this_est_bounds<-newrow
est_bounds<-rbind(est_bounds, newrow)

## "homegrown" sets: these contain the points
for (this_size_alpha in c(size_alpha, 2*size_alpha)){
  vec_lower_tail_probs<-seq(0, this_size_alpha, length=size_asym_alpha_grid)
  tmp_array<-array(NA, dim=c(size_asym_alpha_grid, 3), dimnames=list(1:size_asym_alpha_grid, c("lb", "ub", "width")))
  for (rr in 1:size_asym_alpha_grid){
    this_lower_tail_prob<-vec_lower_tail_probs[rr]
    this_upper_tail_prob<-this_size_alpha-this_lower_tail_prob
    tmp_array[rr,c("lb", "ub")]<-c(quantile(lb, this_lower_tail_prob), quantile(ub, 1-this_lower_tail_prob))
  }
  tmp_array[,"width"]<-tmp_array[,"ub"] - tmp_array[,"lb"]
  row_for_best_conf_set<-which.min(tmp_array[,"width"])
  best_conf_set<-tmp_array[row_for_best_conf_set,]
  newrow<-data.frame("delta_h", 2, 1-this_size_alpha, 
                     best_conf_set["lb"], 
                     best_conf_set["ub"])
  names(newrow)<-names(homegrown_point_conf_sets)
  homegrown_point_conf_sets<-rbind(homegrown_point_conf_sets, newrow)
}

this_version<-this_version+1
print(paste("version:", this_version))

## constant returns to scale
lb<- (pi_intercept_sim + pi_slope_sim)/(1 + pi_slope_sim)  
ub<- (pi_intercept_sim + pi_slope_sim)/(1 + pi_slope_sim)  
lb<- pmax(underline_delta, pmin(overline_delta, lb))
ub<- pmax(underline_delta, pmin(overline_delta, ub))
lb_ub_by_version[,"lb",this_version]<-lb
lb_ub_by_version[,"ub",this_version]<-ub

### est bounds
newrow<-data.frame("delta_h", 3, 
                   max(underline_delta, mean(lb)), 
                   min(overline_delta, mean(ub)))
names(newrow)<-names(est_bounds)
this_est_bounds<-newrow
est_bounds<-rbind(est_bounds, newrow)


## "homegrown" sets: these contain the points
for (this_size_alpha in c(size_alpha, 2*size_alpha)){
  vec_lower_tail_probs<-seq(0, this_size_alpha, length=size_asym_alpha_grid)
  tmp_array<-array(NA, dim=c(size_asym_alpha_grid, 3), dimnames=list(1:size_asym_alpha_grid, c("lb", "ub", "width")))
  for (rr in 1:size_asym_alpha_grid){
    this_lower_tail_prob<-vec_lower_tail_probs[rr]
    this_upper_tail_prob<-this_size_alpha-this_lower_tail_prob
    tmp_array[rr,c("lb", "ub")]<-c(quantile(lb, this_lower_tail_prob), quantile(ub, 1-this_lower_tail_prob))
  }
  tmp_array[,"width"]<-tmp_array[,"ub"] - tmp_array[,"lb"]
  row_for_best_conf_set<-which.min(tmp_array[,"width"])
  best_conf_set<-tmp_array[row_for_best_conf_set,]
  newrow<-data.frame("delta_h", 3, 1-this_size_alpha, 
                     best_conf_set["lb"], 
                     best_conf_set["ub"])
  names(newrow)<-names(homegrown_point_conf_sets)
  homegrown_point_conf_sets<-rbind(homegrown_point_conf_sets, newrow)
}


## delta_I
this_version<-this_version+1
print(paste("version:", this_version))

## no assumption about RTS
lb<- -pi_intercept_sim/pi_slope_sim
ub<- (1-pi_intercept_sim)/pi_slope_sim
lb<- pmax(underline_delta, pmin(overline_delta, lb))
ub<- pmax(underline_delta, pmin(overline_delta, ub))
lb_ub_by_version[,"lb",this_version]<-lb
lb_ub_by_version[,"ub",this_version]<-ub

newrow<-data.frame("delta_I", 1, 
                   max(underline_delta, mean(lb)), 
                   min(overline_delta, mean(ub)))
names(newrow)<-names(est_bounds)
this_est_bounds<-newrow
est_bounds<-rbind(est_bounds, newrow)


## "homegrown" sets: these contain the points
for (this_size_alpha in c(size_alpha, 2*size_alpha)){
  vec_lower_tail_probs<-seq(0, this_size_alpha, length=size_asym_alpha_grid)
  tmp_array<-array(NA, dim=c(size_asym_alpha_grid, 3), dimnames=list(1:size_asym_alpha_grid, c("lb", "ub", "width")))
  for (rr in 1:size_asym_alpha_grid){
    this_lower_tail_prob<-vec_lower_tail_probs[rr]
    this_upper_tail_prob<-this_size_alpha-this_lower_tail_prob
    tmp_array[rr,c("lb", "ub")]<-c(quantile(lb, this_lower_tail_prob), quantile(ub, 1-this_lower_tail_prob))
  }
  tmp_array[,"width"]<-tmp_array[,"ub"] - tmp_array[,"lb"]
  row_for_best_conf_set<-which.min(tmp_array[,"width"])
  best_conf_set<-tmp_array[row_for_best_conf_set,]
  newrow<-data.frame("delta_I", 1, 1-this_size_alpha, 
                     best_conf_set["lb"], 
                     best_conf_set["ub"])
  names(newrow)<-names(homegrown_point_conf_sets)
  homegrown_point_conf_sets<-rbind(homegrown_point_conf_sets, newrow)
}

this_version<-this_version+1
print(paste("version:", this_version))

## non-increasing returns to scale
### est bounds
lb<- -pi_intercept_sim/pi_slope_sim
ub<- (1-pi_intercept_sim)/(1+pi_slope_sim)
lb<- pmax(underline_delta, pmin(overline_delta, lb))
ub<- pmax(underline_delta, pmin(overline_delta, ub))
lb_ub_by_version[,"lb",this_version]<-lb
lb_ub_by_version[,"ub",this_version]<-ub

newrow<-data.frame("delta_I", 2, 
                   max(underline_delta, mean(lb)), 
                   min(overline_delta, mean(ub)))
names(newrow)<-names(est_bounds)
this_est_bounds<-newrow
est_bounds<-rbind(est_bounds, newrow)

## "homegrown": sets: these contain the points
for (this_size_alpha in c(size_alpha, 2*size_alpha)){
  vec_lower_tail_probs<-seq(0, this_size_alpha, length=size_asym_alpha_grid)
  tmp_array<-array(NA, dim=c(size_asym_alpha_grid, 3), dimnames=list(1:size_asym_alpha_grid, c("lb", "ub", "width")))
  for (rr in 1:size_asym_alpha_grid){
    this_lower_tail_prob<-vec_lower_tail_probs[rr]
    this_upper_tail_prob<-this_size_alpha-this_lower_tail_prob
    tmp_array[rr,c("lb", "ub")]<-c(quantile(lb, this_lower_tail_prob), quantile(ub, 1-this_lower_tail_prob))
  }
  tmp_array[,"width"]<-tmp_array[,"ub"] - tmp_array[,"lb"]
  row_for_best_conf_set<-which.min(tmp_array[,"width"])
  best_conf_set<-tmp_array[row_for_best_conf_set,]
  newrow<-data.frame("delta_I", 2, 1-this_size_alpha, 
                     best_conf_set["lb"], 
                     best_conf_set["ub"])
  names(newrow)<-names(homegrown_point_conf_sets)
  homegrown_point_conf_sets<-rbind(homegrown_point_conf_sets, newrow)
}

this_version<-this_version+1
print(paste("version:", this_version))

## constant returns to scale
### est bounds
lb<- (1-pi_intercept_sim)/(1+pi_slope_sim)
ub<- (1-pi_intercept_sim)/(1+pi_slope_sim)
lb<- pmax(underline_delta, pmin(overline_delta, lb))
ub<- pmax(underline_delta, pmin(overline_delta, ub))
lb_ub_by_version[,"lb",this_version]<-lb
lb_ub_by_version[,"ub",this_version]<-ub

newrow<-data.frame("delta_I", 3, 
                   max(underline_delta, mean(lb)), 
                   min(overline_delta, mean(ub)))
names(newrow)<-names(est_bounds)
this_est_bounds<-newrow
est_bounds<-rbind(est_bounds, newrow)


## "homegrown" sets: these contain the points
for (this_size_alpha in c(size_alpha, 2*size_alpha)){
  vec_lower_tail_probs<-seq(0, this_size_alpha, length=size_asym_alpha_grid)
  tmp_array<-array(NA, dim=c(size_asym_alpha_grid, 3), dimnames=list(1:size_asym_alpha_grid, c("lb", "ub", "width")))
  for (rr in 1:size_asym_alpha_grid){
    this_lower_tail_prob<-vec_lower_tail_probs[rr]
    this_upper_tail_prob<-this_size_alpha-this_lower_tail_prob
    tmp_array[rr,c("lb", "ub")]<-c(quantile(lb, this_lower_tail_prob), quantile(ub, 1-this_lower_tail_prob))
  }
  tmp_array[,"width"]<-tmp_array[,"ub"] - tmp_array[,"lb"]
  row_for_best_conf_set<-which.min(tmp_array[,"width"])
  best_conf_set<-tmp_array[row_for_best_conf_set,]
  newrow<-data.frame("delta_I", 3, 1-this_size_alpha, 
                     best_conf_set["lb"], 
                     best_conf_set["ub"])
  names(newrow)<-names(homegrown_point_conf_sets)
  homegrown_point_conf_sets<-rbind(homegrown_point_conf_sets, newrow)
}


# save output
save(lb_ub_by_version, file=paste0("./output/", output_path, "/lb_ub_by_version_", paste0(nSamp, "_", size_asym_alpha_grid)))
write.csv(homegrown_point_conf_sets, file=paste0("./output/", output_path, "/homegrown_point_conf_sets_", paste0(nSamp, "_", size_asym_alpha_grid), ".csv"))

## plot simulated CIs
tikz(paste0("./output/", output_path,"/sim_CI_plot.tex"), standAlone=TRUE)
plot(NULL, xlim=c(0,1), ylim=c(1,6))
for (vv in 1:6){	
  segments(x0=lb_ub_by_version[1:min(nSamp,1000),"lb",vv]	, x1=lb_ub_by_version[1:min(nSamp,1000),"ub",vv]	, y0=vv, y1=vv, col=rgb(0,1,1, alpha=1/100), lwd=30)	
}
dev.off()

## "Tufte"-style CIs!
to_use_conf_sets<-homegrown_point_conf_sets
est_and_conf_sets_95<-rbind(cbind(est_bounds, lsize=1), cbind(subset(to_use_conf_sets, size==0.95)[,names(est_bounds)], lsize=4))

tikz(file=paste0("./output/", output_path, "/delta_h_conf_sets_95_", paste0(nSamp, "_", size_asym_alpha_grid), ".tex"), standAlone=FALSE, sanitize=TRUE, height=7, width=7)
this_plot <- ggplot(data=subset(est_and_conf_sets_95, parameter=="delta_h"), aes(x = factor(ass), xend = factor(ass), y=lb, yend=ub, size=(1/lsize^2), alpha=1/lsize)) + 
              geom_segment(lineend="butt", linejoin="mitre") + 
              geom_segment(data=subset(est_and_conf_sets_95, lsize==1 & ass==3 & parameter=="delta_h"), aes(x = factor(ass), xend = factor(ass), y = lb - point_id_bump, yend = ub + point_id_bump), lineend="butt", linejoin="mitre") + 
              theme_tufte(ticks=FALSE) + theme(legend.position = "none", axis.text=element_text(size=rel(2))) + xlab(NULL) + ylab(NULL) + 
              geom_hline(yintercept=c(0,1), alpha=0.5, linetype="dashed", linewidth=0.25) + scale_x_discrete(labels=c("1" = "None", "2"="NIRS", "3"="CRS"))
print(this_plot)
dev.off()

tikz(file=paste0("./output/", output_path, "/delta_I_conf_sets_95_", paste0(nSamp, "_", size_asym_alpha_grid), ".tex"), standAlone=FALSE, sanitize=TRUE, height=7, width=7)
this_plot <- ggplot(data=subset(est_and_conf_sets_95, parameter=="delta_I"), aes(x = factor(ass), xend = factor(ass), y=lb, yend=ub, size=(1/lsize^2), alpha=1/lsize)) + 
              geom_segment(lineend="butt", linejoin="mitre") + 
              geom_segment(data=subset(est_and_conf_sets_95, lsize==1 & ass==3 & parameter=="delta_I"), aes(x = factor(ass), xend = factor(ass), y = lb - point_id_bump, yend = ub + point_id_bump, size=lsize/20), lineend="butt", linejoin="mitre") + 
              theme_tufte(ticks=FALSE) + theme(legend.position = "none", axis.text=element_text(size=rel(2))) + xlab(NULL) + ylab(NULL) + 
              geom_hline(yintercept=c(0,1), alpha=0.5, linetype="dashed", size=0.25) + scale_x_discrete(labels=c("1" = "None", "2"="NIRS", "3"="CRS"))
print(this_plot)
dev.off()

conf_set_95<-subset(to_use_conf_sets, size==0.95)[,names(est_bounds)]
names(conf_set_95)[3:4]<-paste0(names(conf_set_95)[3:4], "_95")
write.csv(merge(est_bounds, conf_set_95, by=c("parameter", "ass")), file=paste0("./output/", output_path, "/est_bounds_and_95_conf_sets_", paste0(nSamp, "_", size_asym_alpha_grid), ".csv"))

est_and_conf_sets_90_and_95<-rbind(cbind(est_bounds, lsize=1), 
                                   cbind(subset(to_use_conf_sets, size==0.95)[,names(est_bounds)], lsize=4), 
                                   cbind(subset(to_use_conf_sets, size==0.90)[,names(est_bounds)], lsize=2))

tikz(file=paste0("./output/", output_path, "/delta_h_conf_sets_90_and_95_", paste0(nSamp, "_", size_asym_alpha_grid), ".tex"), standAlone=FALSE, sanitize=TRUE, height=7, width=7)
this_plot <- ggplot(data=subset(est_and_conf_sets_90_and_95, parameter=="delta_h"), aes(x=factor(ass), xend=factor(ass), y=lb, yend=ub, size=(1/lsize^2), alpha=1/lsize)) + 
              geom_segment(lineend="butt", linejoin="mitre") +
              geom_segment(data=subset(est_and_conf_sets_90_and_95, lsize==1 & ass==3 & parameter=="delta_h"), aes(x=3-0.04, xend=3+0.04, y=lb, yend=lb, size=lsize/20), lineend="butt", linejoin="mitre") + 
              theme_tufte(ticks=FALSE) + theme(legend.position = "none", axis.text=element_text(size=rel(2))) + xlab(NULL) + ylab(NULL) + 
              geom_hline(yintercept=c(0,1), alpha=0.5, linetype="dashed", size=0.25) + scale_x_discrete(labels=c("1" = "None", "2" = "NIRS", "3" = "CRS"))
print(this_plot)
dev.off()

tikz(file=paste0("./output/", output_path, "/delta_I_conf_sets_90_and_95_", paste0(nSamp, "_", size_asym_alpha_grid), ".tex"), standAlone=FALSE, sanitize=TRUE, height=7, width=7)
this_plot <- ggplot(data=subset(est_and_conf_sets_90_and_95, parameter=="delta_I"), aes(x=factor(ass), xend=factor(ass), y=lb, yend=ub, size=(1/lsize^2), alpha=1/lsize)) + 
              geom_segment(lineend="butt", linejoin="mitre") +
              geom_segment(data=subset(est_and_conf_sets_90_and_95, lsize==1 & ass==3 & parameter=="delta_I"), aes(x=3-0.04, xend=3+0.04, y=lb, yend=lb, size=lsize/20), lineend="butt", linejoin="mitre") + 
              theme_tufte(ticks=FALSE) + theme(legend.position = "none", axis.text=element_text(size=rel(2))) + xlab(NULL) + ylab(NULL) + 
              geom_hline(yintercept=c(0,1), alpha=0.5, linetype="dashed", size=0.25) + scale_x_discrete(labels=c("1" = "None", "2" = "NIRS", "3" = "CRS"))
print(this_plot)
dev.off()

conf_set_90<-subset(to_use_conf_sets, size==0.90)[,names(est_bounds)]
names(conf_set_90)[3:4]<-paste0(names(conf_set_90)[3:4], "_90")
write.csv(merge(merge(est_bounds, conf_set_95, by=c("parameter", "ass")), conf_set_90, by=c("parameter", "ass")), file=paste0("./output/", output_path, "/est_bounds_and_90_95_conf_sets_", paste0(nSamp, "_", size_asym_alpha_grid), ".csv"))




