est_pars_samp<-function(est_data, samp=-99){

# create pooled dataset for pooled regression with lags
	# pid year 
	# pool_avg_t: NA in 1997, avg_t_98_99 in 98_99, avg_t in 2000
	# lag_pool_avg_t: NA in 1997, avg_t_97 in 98_99, avg_t_98_99 in 2000
	pooled_data<-subset(est_data, select=c(pupid, schoolid, year, treated, treatgrp, avg_t, avg_t_1997, avg_t_1998_1999, absent_school, absent_classroom, teso, sexdum))
	pooled_data<-pooled_data[!duplicated(pooled_data),]
	pooled_data$pool_pupid<-pooled_data$pupid
	pooled_data$pool_schoolid<-pooled_data$schoolid
	pooled_data$pool_year<-NA
	pooled_data$pool_avg_t<-NA
	pooled_data$pool_lag_avg_t<-NA
	pooled_data$pool_treated<-pooled_data$treated
	pooled_data$pool_treatgrp<-pooled_data$treatgrp
	pooled_data$pool_absent_school<-pooled_data$absent_school # teacher is absent at school site visit
	pooled_data$pool_absent_classroom<-pooled_data$absent_classroom # teacher is absent in the classroom site visit
	pooled_data$pool_teso<-pooled_data$teso
	pooled_data$pool_sexdum<-pooled_data$sexdum
	pooled_data[pooled_data$year==1997,]$pool_year<-0
	pooled_data[pooled_data$year==1998 | pooled_data$year==1999,]$pool_year<-1
	pooled_data[pooled_data$year==2000,]$pool_year<-2
	pooled_data[pooled_data$pool_year==0,]$pool_avg_t<-pooled_data[pooled_data$pool_year==0,]$avg_t_1997
	pooled_data[pooled_data$pool_year==1,]$pool_avg_t<-pooled_data[pooled_data$pool_year==1,]$avg_t_1998_1999
	pooled_data[pooled_data$pool_year==2,]$pool_avg_t<-pooled_data[pooled_data$pool_year==2,]$avg_t
	pooled_data[pooled_data$pool_year==1,]$pool_lag_avg_t<-pooled_data[pooled_data$pool_year==1,]$avg_t_1997
	pooled_data[pooled_data$pool_year==2,]$pool_lag_avg_t<-pooled_data[pooled_data$pool_year==2,]$avg_t_1998_1999
	pooled_data<-subset(pooled_data, select=c(grep("pool_", names(pooled_data))))
	pooled_data<-pooled_data[!duplicated(pooled_data),]

# ATE y1, y2
	ATE_reg_pooled<-lm(avg_t ~ -1 + I(year==1997) + I(year==1998 | year==1999) + I(year==2000) +I(year==1997*treated) + I(year==1998*treated |year==1999*treated) + I(year==2000*treated), data=subset(est_data, pupid_year_count==1))
	coef_names<-c("I(year == 1998 * treated | year == 1999 * treated)TRUE", "I(year == 2000 * treated)TRUE")
	y_ATE_coefs<-coef(ATE_reg_pooled)[coef_names]
	nice_names<-c("Delta_y_1_hat","Delta_y_2_hat")
	names(y_ATE_coefs)<-nice_names
	Delta_y_1_hat<-y_ATE_coefs["Delta_y_1_hat"]
	Delta_y_2_hat<-y_ATE_coefs["Delta_y_2_hat"]

## persistence (beta_y) uses only control group data
	this_control_pooled<-subset(pooled_data, pool_treated==0)
	this_resampled_control_pooled<-this_control_pooled[sample(1:dim(this_control_pooled)[1], replace=TRUE),]
	pooled_persistence_reg_1<-lm(pool_avg_t ~ pool_lag_avg_t, data=this_resampled_control_pooled)
	beta_y_hat<-coef(pooled_persistence_reg_1)["pool_lag_avg_t"]

# leisure (complement of) regressions
# school level averages (don't have teacher IDs)
	school_level_pooled_data<-with(pooled_data, aggregate(pooled_data, list(pool_schoolid, pool_year), mean))
	# need to re-draw data at school level
	# stratify by treatment group
	this_school_treated_pooled<-subset(school_level_pooled_data, pool_treated==1)
	this_school_control_pooled<-subset(school_level_pooled_data, pool_treated==0)	
	# re-sample only half the observations to get the standard errors right
	this_resampled_school_treated_pooled<-this_school_treated_pooled[sample(1:dim(this_school_treated_pooled)[1], size=round(dim(this_school_treated_pooled)[1]/2), replace=TRUE),]
	this_resampled_school_control_pooled<-this_school_control_pooled[sample(1:dim(this_school_control_pooled)[1], size=round(dim(this_school_control_pooled)[1]/2), replace=TRUE),]
	this_resampled_school_data<-rbind(this_resampled_school_treated_pooled, this_resampled_school_control_pooled)

	school_level_pooled_absent_school_reg<-lm(pool_absent_school ~ pool_treated + I(pool_treated * pool_year==2) + factor(pool_year), data=this_resampled_school_data)
	Delta_l_1_hat<-coef(school_level_pooled_absent_school_reg)["pool_treated"]

	list(est_hat=data.frame(Delta_y_1_sim=Delta_y_1_hat, Delta_y_2_sim=Delta_y_2_hat, beta_y_sim=beta_y_hat, Delta_l_1_sim=Delta_l_1_hat, row.names=samp), this_data=pooled_data, this_school_data=this_resampled_school_data)
}


### estimates based on original (not resampled) Glewwe data, for making regression tables

# create pooled dataset for pooled regression with lags
	# pid year 
	# pool_avg_t: NA in 1997, avg_t_98_99 in 98_99, avg_t in 2000
	# lag_pool_avg_t: NA in 1997, avg_t_97 in 98_99, avg_t_98_99 in 2000
	pooled_data<-subset(glewwe, select=c(pupid, schoolid, year, treated, treatgrp, avg_t, avg_t_1997, avg_t_1998_1999, absent_school, absent_classroom, teso, sexdum))
	pooled_data<-pooled_data[!duplicated(pooled_data),]
	pooled_data$pool_pupid<-pooled_data$pupid
	pooled_data$pool_schoolid<-pooled_data$schoolid
	pooled_data$pool_year<-NA
	pooled_data$pool_avg_t<-NA
	pooled_data$pool_lag_avg_t<-NA
	pooled_data$pool_treated<-pooled_data$treated
	pooled_data$pool_treatgrp<-pooled_data$treatgrp
	pooled_data$pool_absent_school<-pooled_data$absent_school # teacher is absent at school site visit
	pooled_data$pool_absent_classroom<-pooled_data$absent_classroom # teacher is absent in the classroom visit
	pooled_data$pool_teso<-pooled_data$teso
	pooled_data$pool_sexdum<-pooled_data$sexdum
	pooled_data[pooled_data$year==1997,]$pool_year<-0
	pooled_data[pooled_data$year==1998 | pooled_data$year==1999,]$pool_year<-1
	pooled_data[pooled_data$year==2000,]$pool_year<-2
	pooled_data[pooled_data$pool_year==0,]$pool_avg_t<-pooled_data[pooled_data$pool_year==0,]$avg_t_1997
	pooled_data[pooled_data$pool_year==1,]$pool_avg_t<-pooled_data[pooled_data$pool_year==1,]$avg_t_1998_1999
	pooled_data[pooled_data$pool_year==2,]$pool_avg_t<-pooled_data[pooled_data$pool_year==2,]$avg_t
	pooled_data[pooled_data$pool_year==1,]$pool_lag_avg_t<-pooled_data[pooled_data$pool_year==1,]$avg_t_1997
	pooled_data[pooled_data$pool_year==2,]$pool_lag_avg_t<-pooled_data[pooled_data$pool_year==2,]$avg_t_1998_1999
	pooled_data<-subset(pooled_data, select=c(grep("pool_", names(pooled_data))))
	pooled_data<-pooled_data[!duplicated(pooled_data),]

# ATE y1, y2
	ATE_reg_pooled<-lm(avg_t ~ -1 + I(year==1997) + I(year==1998 | year==1999) + I(year==2000) +I(year==1997*treated) + I(year==1998*treated |year==1999*treated) + I(year==2000*treated), data=subset(glewwe, pupid_year_count==1))
	coef_names<-c("I(year == 1998 * treated | year == 1999 * treated)TRUE", "I(year == 2000 * treated)TRUE")
	y_ATE_coefs<-coef(ATE_reg_pooled)[coef_names]
	nice_names<-c("Delta_y_1_hat","Delta_y_2_hat")
	names(y_ATE_coefs)<-nice_names
	Delta_y_1_hat<-y_ATE_coefs["Delta_y_1_hat"]
	Delta_y_2_hat<-y_ATE_coefs["Delta_y_2_hat"]

## persistence (beta_y) uses only control group data
	control_pooled<-subset(pooled_data, pool_treated==0)
	pooled_persistence_reg_1<-lm(pool_avg_t ~ pool_lag_avg_t, data=control_pooled)
	beta_y_hat<-coef(pooled_persistence_reg_1)["pool_lag_avg_t"]

# leisure (complement of) regressions
# school level averages (don't have teacher IDs)
	school_level_pooled_data<-with(pooled_data, aggregate(pooled_data, list(pool_schoolid, pool_year), mean))
	# need to re-draw data at school level
	# stratify by treatment group
	this_school_treated_pooled<-subset(school_level_pooled_data, pool_treated==1)
	this_school_control_pooled<-subset(school_level_pooled_data, pool_treated==0)	

	school_level_pooled_absent_school_reg<-lm(pool_absent_school ~ pool_treated + I(pool_treated * pool_year==2) + factor(pool_year), data=school_level_pooled_data)
	Delta_l_1_hat<-coef(school_level_pooled_absent_school_reg)["pool_treated"]

glewwe_estimates<-data.frame(Delta_y_1_sim=Delta_y_1_hat, Delta_y_2_sim=Delta_y_2_hat, beta_y_sim=beta_y_hat, Delta_l_1_sim=Delta_l_1_hat)



